@@ -1023,13 +1023,14 @@ namespace OpenBve {
 									case Interface.Command.CameraInterior:
 										// camera: interior
 										SaveCameraSettings();
+										bool lookahead = false;
 										if (World.CameraMode != World.CameraViewMode.InteriorLookAhead & World.CameraRestriction == World.CameraRestrictionMode.NotAvailable) {
-											World.CameraMode = World.CameraViewMode.InteriorLookAhead;
 											Game.AddMessage(Interface.GetInterfaceString("notification_interior_lookahead"), Game.MessageDependency.None, Interface.GameMode.Expert, Game.MessageColor.Blue, Game.SecondsSinceMidnight + 2.0);
+											lookahead = true;
 										} else {
-											World.CameraMode = World.CameraViewMode.Interior;
 											Game.AddMessage(Interface.GetInterfaceString("notification_interior"), Game.MessageDependency.None, Interface.GameMode.Expert, Game.MessageColor.Blue, Game.SecondsSinceMidnight + 2.0);
 										}
+										World.CameraMode = World.CameraViewMode.Interior;
 										RestoreCameraSettings();
 										for (int j = 0; j <= TrainManager.PlayerTrain.DriverCar; j++) {
 											if (TrainManager.PlayerTrain.Cars[j].CarSections.Length != 0) {
@@ -1051,6 +1052,9 @@ namespace OpenBve {
 												World.InitializeCameraRestriction();
 											}
 										}
+										if (lookahead) {
+											World.CameraMode = World.CameraViewMode.InteriorLookAhead;
+										}
 										break;
 									case Interface.Command.CameraExterior:
 										// camera: exterior
